/*!
 * quasar-ui-json-api-viewer v1.0.4
 * (c) 2020 Jeff Galbraith <jeff@quasar.dev>
 * Released under the MIT License.
 */

(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('vue'), require('quasar'), require('@quasar/quasar-ui-qmarkdown/src/index.js'), require('@quasar/quasar-ui-qribbon')) :
  typeof define === 'function' && define.amd ? define(['exports', 'vue', 'quasar', '@quasar/quasar-ui-qmarkdown/src/index.js', '@quasar/quasar-ui-qribbon'], factory) :
  (global = global || self, factory(global.jsonApiViewer = {}, global.Vue, global.Quasar, global.index_js, global.QRibbon));
}(this, (function (exports, Vue, quasar, index_js, quasarUiQribbon) { 'use strict';

  if (Vue === void 0) {
    console.error('[ Quasar ] Vue is required to run. Please add a script tag for it before loading Quasar.')
    return
  }
  Vue = Vue && Vue.hasOwnProperty('default') ? Vue['default'] : Vue;

  var version = "1.0.4";

  var JsonApiViewerMixin = {
    methods: {

      copyHeading: function copyHeading (id, message, color, textColor, icon, position, timeout) {
        if ( message === void 0 ) message = 'Anchor has been copied to clipboard.';
        if ( color === void 0 ) color = 'white';
        if ( textColor === void 0 ) textColor = 'primary';
        if ( icon === void 0 ) icon = 'done';
        if ( position === void 0 ) position = 'top';
        if ( timeout === void 0 ) timeout = 2000;

        if (window && window.location && document && document.createElement) {
          var text = window.location.origin + window.location.pathname + '#' + id;

          var textArea = document.createElement('textarea');
          textArea.className = 'fixed-top';
          textArea.value = text;
          document.body.appendChild(textArea);
          textArea.focus();
          textArea.select();

          document.execCommand('copy');
          document.body.removeChild(textArea);

          this.$q.notify({
            message: message,
            color: color,
            textColor: textColor,
            icon: icon,
            position: position,
            timeout: timeout
          });
        }
      },

      slugify: function slugify (str) {
        return encodeURIComponent(String(str).trim().replace(/\s+/g, '-'))
      }
    }
  };

  // Utils

  var NAME_PROP_COLOR = [
    'bg-orange-8',
    'bg-accent',
    'bg-secondary',
    'bg-warning'
  ];

  var JsonApiItem = {
    name: 'JsonApiItem',

    props: {
      name: {
        type: String,
        required: true
      },
      type: {
        type: String,
        default: 'props'
      },
      json: {
        type: Object,
        required: true
      }
    },

    methods: {
      getMethodName: function getMethodName (title, json) {
        var name;

        name = ' [';

        if (json.returns) {
          name += json.returns.type;
        } else {
          name += 'void 0';
        }

        name += '] ';

        if (json.params === void 0) {
          name += title + ' ()';
        } else {
          name += title + ' (' + Object.keys(json.params).join(', ') + ')';
        }

        return name
      },

      getEventName: function getEventName () {
        var name = '@' + this.name + ' => function';

        if (this.json.params === void 0) {
          return name + ' ()'
        }

        name += ' (' + Object.keys(this.json.params).join(', ') + ')';

        return name
      },

      __renderSubitem: function __renderSubitem (h, name, json, level) {
        if ( level === void 0 ) level = 0;

        if (json.type === 'Function') {
          name = this.getMethodName(name, json);
        }
        return h('div', {
          staticClass: 'component-api__row component-api__row--bordered row'
        }, [
          this.__renderName(h, name, NAME_PROP_COLOR[level]),
          this.__renderType(h, json),
          this.__renderAddedIn(h, json),
          this.__renderRequired(h, json),
          this.__renderSync(h, json),
          this.__renderDefault(h, json),
          this.__renderApplicable(h, json),

          this.__renderDesc(h, json),
          this.__renderValues(h, json),
          this.__renderExamples(h, json),
          this.__renderParams(h, json, level + 1),
          this.__renderDefinitions(h, json, level + 1),
          this.__renderScope(h, json, level + 1),
          this.__renderReturns(h, json, level + 1)
        ])
      },

      __renderParams: function __renderParams (h, json, level) {
        var this$1 = this;
        if ( level === void 0 ) level = 0;

        if (json.params === void 0) { return '' }
        var keys = Object.keys(json.params);
        return h('div', {
          staticClass: 'component-api__row--item full-width'
        }, [
          h('div', {
            staticClass: 'component-api__row--label'
          }, 'Parameter' + (Object.keys(json.params).length > 1 ? 's' : '')),
          h('div', {
          }, [
            keys.map(function (key) { return this$1.__renderSubitem(h, key, json.params[key], level); })
          ])
        ])
      },

      __renderDefinitions: function __renderDefinitions (h, json, level) {
        var this$1 = this;
        if ( level === void 0 ) level = 0;

        if (json.definition === void 0) { return '' }
        var keys = Object.keys(json.definition);
        return h('div', {
          staticClass: 'component-api__row--item full-width'
        }, [
          h('div', {
            staticClass: 'component-api__row--label'
          }, 'Definition' + (Object.keys(json.definition).length > 1 ? 's' : '')),
          h('div', {
          }, [
            keys.map(function (key) { return this$1.__renderSubitem(h, key, json.definition[key], level); })
          ])
        ])
      },

      __renderScope: function __renderScope (h, json, level) {
        var this$1 = this;
        if ( level === void 0 ) level = 0;

        if (json.scope === void 0) { return '' }
        var keys = Object.keys(json.scope);
        return h('div', {
          staticClass: 'component-api__row--item full-width'
        }, [
          h('div', {
            staticClass: 'component-api__row--label'
          }, 'Scope'),
          h('div', {
          }, [
            keys.map(function (key) { return this$1.__renderSubitem(h, key, json.scope[key], level); })
          ])
        ])
      },

      __renderReturns: function __renderReturns (h, json, level) {
        if ( level === void 0 ) level = 0;

        if (json.returns === void 0) { return '' }
        return h('div', {
          staticClass: 'component-api__row--item full-width'
        }, [
          h('div', {
            staticClass: 'component-api__row--label'
          }, 'Returns'),
          h('div', {
          }, [
            json.returns === null && 'null',
            json.returns !== null && this.__renderSubitem(h, void 0, json.returns, level)
          ])
        ])
      },

      __renderValues: function __renderValues (h, json) {
        if (json.values === void 0 || json.values.length <= 0) { return '' }
        return h('div', {
          staticClass: 'component-api__row--item col-auto'
        }, [
          h('div', {
            staticClass: 'component-api__row--label'
          }, 'Value' + (json.values.length > 1 ? 's' : '')),
          h('div', {
            staticClass: 'component-api__row--values'
          }, json.values.join(', '))
        ])
      },

      __renderExample: function __renderExample (h, example) {
        var json = '```js\n' + example + '\n```';
        return h(index_js.QMarkdown, {
          staticClass: 'component-api__row--example'
        }, json)
      },

      __renderExamples: function __renderExamples (h, json) {
        var this$1 = this;

        if (json.examples === void 0 || json.examples.length <= 0) { return '' }
        return h('div', {
          staticClass: 'component-api__row--item col-auto'
        }, [
          h('div', {
            staticClass: 'component-api__row--label'
          }, 'Example' + (json.examples.length > 1 ? 's' : '')),
          h('div', {
            staticClass: 'component-api__row--value'
          }, [
            json.examples.map(function (example, index) { return this$1.__renderExample(h, example); })
          ])
        ])
      },

      __renderDesc: function __renderDesc (h, json) {
        if (json.desc === void 0) { return '' }
        return h('div', {
          staticClass: 'component-api__row--item full-width'
        }, [
          h('div', {
            staticClass: 'component-api__row--label'
          }, 'Description'),
          h('div', {
            staticClass: 'component-api__row--value'
          }, [
            h(index_js.QMarkdown, json.desc)
          ])
        ])
      },

      __renderSync: function __renderSync (h, json) {
        if (json.sync === void 0) { return '' }
        return h('div', {
          staticClass: 'component-api__row--item col-xs-12 col-sm-4'
        }, [
          h('div', {
            staticClass: 'component-api__row--label'
          }, 'Sync'),
          h('div', {
            staticClass: 'component-api__row--value'
          }, [
            h('div', json.sync)
          ])
        ])
      },

      __renderRequired: function __renderRequired (h, json) {
        if (json.required === void 0) { return '' }
        return h('div', {
          staticClass: 'component-api__row--item col-xs-12 col-sm-4'
        }, [
          h('div', {
            staticClass: 'component-api__row--label'
          }, 'Required'),
          h('div', {
            staticClass: 'component-api__row--value'
          }, [
            h('div', json.required)
          ])
        ])
      },

      __renderApplicable: function __renderApplicable (h, json) {
        if (json.applicable === void 0) { return '' }
        return h('div', {
          staticClass: 'component-api__row--item col-xs-12 col-sm-4'
        }, [
          h('div', {
            staticClass: 'component-api__row--label'
          }, 'Applicable'),
          h('div', {
            staticClass: 'component-api__row--value'
          }, [
            h('div', json.applicable.join(', '))
          ])
        ])
      },

      __renderDefault: function __renderDefault (h, json) {
        if (json.default === void 0) { return '' }
        return h('div', {
          staticClass: 'component-api__row--item col-xs-12 col-sm-4'
        }, [
          h('div', {
            staticClass: 'component-api__row--label'
          }, 'Default'),
          h('div', {
            staticClass: 'component-api__row--value'
          }, [
            h('div', json.default)
          ])
        ])
      },

      __renderAddedIn: function __renderAddedIn (h, json) {
        if (json.addedIn === void 0) { return '' }
        return h('div', {
          staticClass: 'component-api__row--item col-xs-12 col-sm-4'
        }, [
          h('div', {
            staticClass: 'component-api__row--label'
          }, 'Added in'),
          h('div', {
            staticClass: 'component-api__row--value'
          }, [
            h('div', json.addedIn)
          ])
        ])
      },

      __renderType: function __renderType (h, json) {
        if (json.type === void 0) { return '' }
        var type = Array.isArray(json.type) ? json.type.join(' | ') : json.type;
        return h('div', {
          staticClass: 'component-api__row--item col-xs-12 col-sm-4'
        }, [
          h('div', {
            staticClass: 'component-api__row--label'
          }, 'Type'),
          h('div', {
            staticClass: 'component-api__row--value'
          }, [
            h('div', type)
          ])
        ])
      },

      __renderName: function __renderName (h, name, color) {
        if (name === void 0) { return '' }
        return h('div', {
          staticClass: 'component-api__row--item col-grow'
        }, [
          h('div', {
            staticClass: 'component-api__row--label'
          }, 'Name'),
          h('div', {
            staticClass: 'component-api__row--value'
          }, [
            h(quasar.QBadge, {
              staticClass: ("property-name " + color)
            }, name)
          ])
        ])
      },

      __render: function __render (h) {
        var name = this.name;
        if (this.type === 'methods') {
          name = this.getMethodName(name, this.json);
        } else if (this.type === 'events') {
          name = this.getEventName(name, this.json);
        }
        var level = 0;
        return h('div', {
          staticClass: 'row full-width'
        }, [
          this.__renderName(h, name, NAME_PROP_COLOR[level]),
          this.__renderType(h, this.json),
          this.__renderAddedIn(h, this.json),
          this.__renderRequired(h, this.json),
          this.__renderSync(h, this.json),
          this.__renderDefault(h, this.json),
          this.__renderApplicable(h, this.json),

          this.__renderDesc(h, this.json),
          this.__renderValues(h, this.json),
          this.__renderExamples(h, this.json),
          this.__renderParams(h, this.json, level + 1),
          this.__renderDefinitions(h, this.json, level + 1),
          this.__renderScope(h, this.json, level + 1),
          this.__renderReturns(h, this.json, level + 1)
        ])
      }
    },

    render: function render (h) {
      return this.__render(h)
    }
  };

  // Utils

  var JsonApiList = {
    name: 'JsonApiList',

    props: {
      name: {
        type: String,
        required: true
      },
      json: {
        type: Object,
        required: true
      }
    },

    data: function data () {
      return {}
    },

    computed: {
      headings: function headings () {
        return Object.keys(this.json)
      }
    },

    methods: {
      __renderItems: function __renderItems (h) {
        var this$1 = this;

        return [].concat( this.headings.map(function (heading) { return h(quasar.QItem, {
          key: this$1.name + '-' + heading,
          staticClass: 'component-api__list-item'
        }, [
          h(JsonApiItem, {
            props: {
              name: heading,
              type: this$1.name,
              json: this$1.json[heading]
            }
          })
        ]); }) )
      },

      __render: function __render (h) {
        var content = Object.keys(this.json).length !== 0
          ? this.__renderItems(h)
          : h('div', { staticClass: 'q-pa-md text-grey-7' }, [
              'No matching entries found. Please refine the filter.'
            ]);

        return h(quasar.QList, {
          staticClass: 'component-api__list',
          props: {
            separator: true
          }
        }, [
          content
        ])
      }
    },

    render: function render (h) {
      return this.__render(h)
    }
  };

  // Mixins

  var JsonApiViewer = {
    name: 'JsonApiViewer',

    mixins: [JsonApiViewerMixin],

    props: {
      title: {
        type: String,
        required: true
      },
      json: {
        type: Object,
        required: true
      },
      type: {
        type: String,
        default: 'Vue Component'
      },
      startingTab: String,
      startingInnerTab: String
    },

    data: function data () {
      return {
        ready: false,
        currentTab: 'props',
        currentInnerTab: 'model',
        api: void 0,
        filteredApi: void 0,
        filter: '',
        tabs: [],
        tabCount: {},
        innerTabCount: {},
        innerTabContent: {},
        borderColor: 'lightblue',
        separatorColor: 'light-blue-2'
      }
    },

    mounted: function mounted () {
      this.currentTab = this.startingTab || this.currentTab;
      this.currentInnerTab = this.startingInnerTab || this.currentInnerTab;
      this.__parseJson(this.json);
    },

    computed: {
      slugifiedTitle: function slugifiedTitle () {
        return this.slugify(this.title)
      },

      headings: function headings () {
        return this.tabs
      }
    },

    watch: {
      filter: function filter (val) {
        this.__parseJson(this.json);
      }
    },

    methods: {
      __parseJson: function __parseJson (json) {
        if (json === void 0) {
          // no api
          this.ready = true;
          return
        }

        // deep copy object
        var api = quasar.extend(true, {}, json);

        if (api.type !== void 0) {
          delete api.type;
        }

        if (api.meta) {
          delete api.meta;
        }

        this.__resetFiltered();

        // deal with "props"
        if (api.props !== void 0) {
          // get sorted keys
          var propKeys = Object.keys(api.props).sort();

          // loop through keys to get inner tab content
          for (var j = 0; j < propKeys.length; ++j) {
            var key = propKeys[j];
            var props = api.props[key];
            if (this.innerTabContent[props.category] === void 0) {
              this.$set(this.innerTabContent, props.category, {});
            }
            var apiProps = this.__filterContent(props);
            if (Object.keys(apiProps).length > 0) {
              this.$set(this.innerTabContent[props.category], key, apiProps);
            }
            else {
              delete api.props[key];
            }
          }

          this.$set(this, 'innerTabCount', {});
          var innerKeys = Object.keys(this.innerTabContent);
          for (var k = 0; k < innerKeys.length; ++k) {
            var innerPropKey = innerKeys[k];
            this.$set(this.innerTabCount, innerPropKey, Object.keys(this.innerTabContent[innerPropKey]).length);
          }
        }

        this.__filterTopLevel(api);

        // get a count of items within each top-level tab menu
        var keys = Object.keys(api);
        for (var i = 0; i < keys.length; ++i) {
          var type = keys[i];
          this.$set(this.tabs, type, Object.keys(api[type]).length);
        }

        this.filteredApi = api;

        this.ready = true;
      },

      __filterTopLevel: function __filterTopLevel (api) {
        var keys = Object.keys(api);
        for (var i = 0; i < keys.length; ++i) {
          var type = keys[i];
          if (type !== 'props') {
            // loop through inner content
            var propKeys = Object.keys(api[type]);
            for (var l = 0; l < propKeys.length; ++l) {
              var props = api[type][propKeys[l]];
              var apiProps = this.__filterContent(props);
              if (Object.keys(apiProps).length === 0) {
                delete api[type][propKeys[l]];
              }
            }
          }
        }
      },

      __filterContent: function __filterContent (api) {
        if (this.filter === '') {
          return api
        }

        var found = false;
        var keys = Object.keys(api);
        for (var i = 0; i < keys.length; ++i) {
          var prop = api[keys[i]];
          var type = Object.prototype.toString.call(prop);
          if ('[object Array]' === type) {
            if (this.__filterArray(prop)) {
              found = true;
              break
            }
          }
          else if ('[object String]' === type || '[object Number]' === type) {
            if (this.__filterString(prop)) {
              found = true;
              break
            }
          }
        }

        if (found !== true) {
          return {}
        }

        return api
      },

      // tests the passed string against the filter
      __filterString: function __filterString (str) {
        return String(str).toLowerCase().indexOf(this.filter.toLowerCase()) >= 0
      },

      __filterArray: function __filterArray (arr) {
        for (var i = 0; i < arr.length; ++i) {
          if (this.__filterString(arr[i]) === true) {
            return true
          }
        }
        return false
      },

      __resetFiltered: function __resetFiltered () {
        this.$set(this, 'innerTabContent', {});
        this.$set(this, 'innerTabCount', {});
        this.$set(this, 'tabCount', {});
        this.$set(this, 'tabs', []);
      },

      __onFilter: function __onFilter () {
        if (this.filter !== '') {
          this.filter = '';
        }

        this.$refs.input.focus();
      },

      __renderToolbarTitle: function __renderToolbarTitle (h) {
        var this$1 = this;

        return h(quasar.QToolbarTitle, {
          staticClass: 'example-title',
          on: {
            click: function (e) { this$1.copyHeading(this$1.slugifiedTitle); }
          }
        }, [
          h('span', {
            staticClass: 'ellipsis'
          }, this.title)
        ])
      },

      __renderRibbon: function __renderRibbon (h) {
        return h(quasarUiQribbon.QRibbon, {
          props: {
            position: 'left',
            color: 'rgba(0,0,0,.58)',
            backgroundColor: '#c0c0c0',
            leafColor: '#a0a0a0',
            leafPosition: 'bottom',
            decoration: 'rounded-out'
          }
        }, [
          this.__renderToolbarTitle(h)
        ])
      },

      __renderFilter: function __renderFilter (h) {
        var this$1 = this;

        return h(quasar.QInput, {
          ref: 'input',
          staticClass: 'q-mx-sm',
          style: {
            minWidth: '150px'
          },
          attrs: {
            placeholder: 'Filter...'
          },
          props: {
            value: this.filter,
            inputClass: 'text-right',
            dense: true,
            borderless: true
          },
          on: {
            input: function (v) {
              this$1.filter = v;
            }
          },
          scopedSlots: {
            append: function () { return h(quasar.QIcon, {
              staticClass: 'cursor-pointer',
              props: {
                name: this$1.filter !== '' ? 'clear' : 'search'
              },
              on: {
                click: this$1.__onFilter
              }
            }); }
          }
        })
      },

      __renderToolbar: function __renderToolbar (h) {
        return h(quasar.QToolbar, {
          staticClass: ''
        }, [
          this.__renderRibbon(h),
          h('div', {
            staticClass: 'q-ml-md col-auto text-grey text-caption'
          }, [
            this.$q.screen.gt.xs && this.type
          ]),
          h(quasar.QSpace),
          this.$q.screen.width >= 385 && this.__renderFilter(h)
        ])
      },

      __renderTabs: function __renderTabs (h) {
        var this$1 = this;

        return h(quasar.QTabs, {
          staticClass: 'text-caption' + (!this.$q.dark.isActive ? ' bg-grey-2 text-grey-7' : ''),
          props: {
            value: this.currentTab,
            dense: true,
            activeColor: this.$q.dark.isActive ? 'yellow' : 'primary',
            indicatorColor: this.$q.dark.isActive ? 'yellow' : 'primary',
            align: 'left',
            narrowIndicator: true
          },
          on: {
            input: function (v) { this$1.currentTab = v; }
          }
        }, [].concat( Object.keys(this.tabs).map(function (propKey) { return h(quasar.QTab, {
            key: propKey + '-tab',
            props: {
              name: propKey
            },
            scopedSlots: {
              default: function () { return this$1.__renderTabSlot(h, propKey, this$1.tabs[propKey]); }
            }
          }); }) ))
      },

      __renderTabSlot: function __renderTabSlot (h, label, count, stretch) {
        return h('div', {
          staticClass: 'row no-wrap items-center self-stretch q-pa-xs',
          style: {
            minWidth: stretch === true ? '120px' : void 0
          }
        }, [
          h('span', {
            staticClass: 'q-mr-xs text-uppercase text-weight-medium'
          }, label),
          h('div', {
            staticClass: 'col'
          }),
          count > 0 && h(quasar.QBadge, [ count ])
        ])
      },

      __renderTabPanels: function __renderTabPanels (h) {
        var this$1 = this;

        return h(quasar.QTabPanels, {
          props: {
            value: this.currentTab,
            animated: true
          },
          on: {
            input: function (v) { this$1.currentTab = v; }
          }
        }, [
          this.__renderTabPanel(h)
        ])
      },

      __renderTabPanel: function __renderTabPanel (h) {
        var this$1 = this;

        return [].concat( Object.keys(this.tabs).map(function (propKey) { return h(quasar.QTabPanel, {
          key: propKey + '-panel',
          staticClass: 'q-pa-none',
          props: {
            name: propKey
          }
        }, [
          propKey === 'props' && this$1.__renderInnerTabs(h, propKey, this$1.filteredApi[propKey]),
          propKey !== 'props' && this$1.__renderApiList(h, propKey, this$1.filteredApi[propKey])
        ]); }) )
      },

      __renderApiList: function __renderApiList (h, name, api) {
        return h('div', {
          staticClass: 'component-api__container'
        }, [
          h(JsonApiList, {
            props: {
              name: name,
              json: api
            }
          })
        ])
      },

      __renderInnerTabs: function __renderInnerTabs (h, name, api) {
        var this$1 = this;

        return h('div', {
          staticClass: 'fit row'
        }, [
          h('div', {
            staticClass: 'col-auto row no-wrap q-py-lg' + (!this.$q.dark.isActive ? ' bg-grey-2 text-grey-7' : ''),
          }, [
            h(quasar.QTabs, {
              staticClass: 'text-caption' + (!this.$q.dark.isActive ? ' bg-grey-2 text-grey-7' : ''),
              props: {
                value: this.currentInnerTab,
                dense: true,
                vertical: true,
                activeColor: this.$q.dark.isActive ? 'yellow' : 'primary',
                indicatorColor: this.$q.dark.isActive ? 'yellow' : 'primary',
                align: 'left',
                narrowIndicator: true
              },
              on: {
                input: function (v) { this$1.currentInnerTab = v; }
              }
            }, [].concat( Object.keys(this.innerTabCount).map(function (propKey) { return h(quasar.QTab, {
                key: propKey + '-inner-tab',
                staticClass: 'col-shrink',
                props: {
                  name: propKey
                },
                scopedSlots: {
                  default: function () { return this$1.__renderTabSlot(h, propKey, this$1.innerTabCount[propKey], true); }
                }
              }); }) ))
          ]),
          h(quasar.QSeparator, {
            props: {
              vertical: true,
              color: this.separatorColor
            },
            style: {
              minHeight: '600px'
            }
          }),
          this.__renderInnerTabPanels(h)
        ])
      },

      __renderInnerTabPanels: function __renderInnerTabPanels (h) {
        var this$1 = this;

        return h(quasar.QTabPanels, {
          staticClass: 'col',
          props: {
            value: this.currentInnerTab,
            animated: true,
            transitionPrev: 'slide-down',
            transitionNext: 'slide-up'

          },
          on: {
            input: function (v) { this$1.currentInnerTab = v; }
          }
        }, [
          this.__renderInnerTabPanel(h)
        ])
      },

      __renderInnerTabPanel: function __renderInnerTabPanel (h) {
        var this$1 = this;

        return [].concat( Object.keys(this.innerTabContent).map(function (propKey) { return h(quasar.QTabPanel, {
          key: propKey + '-inner-panel',
          staticClass: 'q-pa-none',
          props: {
            name: propKey
          }
        }, [
          this$1.__renderApiList(h, propKey, this$1.innerTabContent[propKey])
        ]); }) )
      },

      __renderCard: function __renderCard (h) {
        return h(quasar.QCard, {
          staticClass: 'no-shadow',
          props: {
            flat: true,
            bordered: true
          },
          style: {
            border: ((this.borderColor) + " 1px solid")
          }
        }, [
          this.__renderToolbar(h),
          h(quasar.QSeparator, {
            props: {
              color: this.separatorColor
            }
          }),
          this.__renderTabs(h),
          h(quasar.QSpace),
          h(quasar.QSeparator, {
            props: {
              color: this.separatorColor
            }
          }),
          this.__renderTabPanels(h)
        ])
      },

      __renderSection: function __renderSection (h) {
        return h('section', {
          domProps: {
            id: this.slugifiedTitle
          },
          staticClass: 'q-pa-md overflow-auto'
        }, [
          this.__renderCard(h)
        ])
      },

      __render: function __render (h) {
        return h('div', [
          this.__renderSection(h)
        ])
      }
    },

    render: function render (h) {
      if (this.ready === true) {
        return this.__render(h)
      }
      return void 0
    }
  };

  var Plugin = {
    version: version,
    JsonApiViewer: JsonApiViewer,

    install: function install (Vue) {
      Vue.component(JsonApiViewer.name, JsonApiViewer);
    }
  };

  Vue.use(Plugin);

  exports.JsonApiViewer = JsonApiViewer;
  exports.version = version;

  Object.defineProperty(exports, '__esModule', { value: true });

})));
